import { WebView } from 'react-native-webview';
import React from 'react'

interface Props {
  onVisible: boolean,
  authToken: string,
  widgetId: string,
  onCompletion(data : any): void
}

const OTPVerification: React.FC<Props> = ({
  onVisible,
  authToken,
  widgetId,
  onCompletion
}) => {
  function onMessage(data) {
    onCompletion(data.nativeEvent.data)
  }
  var verificationScript = `
  <html>
  <head>
     
  </head>
  <body onload="initOTPWidget()">
  <script type="text/javascript">
  var configuration = {
  widgetId: ":widgetId",
  tokenAuth: ":authToken",
  success: (data) => {
  sendDataToReactNativeApp(data);
  },
  failure: (error) => {
  sendDataToReactNativeApp(error);
  }
  };
  </script>
  <script type="text/javascript" src="https://control.msg91.com/app/assets/otp-provider/otp-provider.js"> </script>
  <script>
  function initOTPWidget() {
  initSendOTP(configuration);
  }
  function sendDataToReactNativeApp(data) {
  window.ReactNativeWebView.postMessage(JSON.stringify(data));
  };
  </script>
  </body>
  </html>`.replace(':widgetId',widgetId).replace(':authToken',authToken)

  if(onVisible){
    return (
      <WebView   
        containerStyle={{position:'absolute', height: '100%', width: '100%' }}
        onMessage={onMessage}
        source={{ html: verificationScript }} />
    )
  }else{
    return null;
  }
   
}

export default OTPVerification